#!/usr/bin/env bash
export PYTHONPATH=$PWD/Assets/site-packages
echo $PYTHONPATH
python3 Assets/SEIR_model.py